@@ -7,7 +7,7 @@ use v5.10.1;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use MRO::Compat;
 
@@ -88,7 +88,17 @@ sub role_import {
     my $class = shift;
     return unless Moo::Role->is_role( $class );
     my $target = caller;
-    Moo::Role->apply_roles_to_package( $target, $class );
+    if ( Moo::Role->is_role( $target ) ) {
+        Moo::Role->apply_roles_to_package( $target, $class );
+    }
+    else {
+        # Prevent installation of the import routine from a tagged role
+        # into the consumer.  Roles won't overwrite an existing method,
+        # so create one which goes away when this block exits.
+        no strict 'refs';    ## no critic
+        local *${ \"${target}::import" } = sub { };
+        Moo::Role->apply_roles_to_package( $target, $class );
+    }
     install_tags( $target, -class => $class );
 }
 
@@ -218,7 +228,7 @@ MooX::TaggedAttributes - Add a tag with an arbitrary value to a an attribute
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
